@@ -1,4 +1,4 @@
-from functools import lru_cache
+from functools import lru_cache, partial
 from pathlib import Path
 from typing import Any, Dict, Iterable, Iterator, List, Optional, Pattern, Union
 
@@ -6,8 +6,11 @@ import click
 import toml
 from pathspec import PathSpec
 
+from . import __version__
 from .report import Report
 
+out = partial(click.secho, bold=True, err=True)
+
 
 @lru_cache()
 def find_project_root(srcs: Iterable[str]) -> Path:
@@ -55,6 +58,19 @@ def parse_pyproject_toml(path_config: str) -> Dict[str, Any]:
     return {k.replace("--", "").replace("-", "_"): v for k, v in config.items()}
 
 
+def dump_toml_config(ctx: click.Context, config: Dict[str, Any] = None):
+    """Prints the provided config object as TOML, if present."""
+    if not config:
+        out(
+            "Oops! Something went wrong! :( curlylint couldn’t find a configuration file.\n"
+            f"curlylint: v{__version__}.\n\n"
+        )
+        ctx.exit(2)
+
+    print(toml.dumps({"tool": {"curlylint": config}}))
+    ctx.exit(0)
+
+
 def read_pyproject_toml(
     ctx: click.Context,
     param: click.Parameter,
@@ -65,9 +81,13 @@ def read_pyproject_toml(
     otherwise.
     """
     assert not isinstance(value, (int, bool)), "Invalid parameter type passed"
+    print_config = ctx.params.get("print_config", False)
+
     if not value:
         value = find_pyproject_toml(ctx.params.get("src", ()))
         if value is None:
+            if print_config:
+                dump_toml_config(ctx)
             return None
 
     try:
@@ -78,11 +98,12 @@ def read_pyproject_toml(
         )
 
     if not config:
+        if print_config:
+            dump_toml_config(ctx)
         return None
 
-    if ctx.params.get("print_config", False):
-        print(toml.dumps({"tool": {"curlylint": config}}))
-        ctx.exit(0)
+    if print_config:
+        dump_toml_config(ctx, config)
 
     if ctx.default_map is None:
         ctx.default_map = {}
